.. -*- mode: rst -*-
.. vi: set ft=rst sts=4 ts=4 sw=4 et tw=79:

.. _chap_cmdline:

**********************
Command line reference
**********************

Main command
============

.. toctree::
   :maxdepth: 1

   generated/man/datalad

Dataset operations
==================

.. toctree::
   :maxdepth: 1

   generated/man/datalad-add
   generated/man/datalad-add-sibling
   generated/man/datalad-create
   generated/man/datalad-get
   generated/man/datalad-create-sibling
   generated/man/datalad-create-sibling-github
   generated/man/datalad-install
   generated/man/datalad-rewrite-urls
   generated/man/datalad-publish
   generated/man/datalad-uninstall
   generated/man/datalad-update
   generated/man/datalad-save
   generated/man/datalad-unlock
   generated/man/datalad-export

Meta data handling
==================

.. toctree::
   :maxdepth: 1

   generated/man/datalad-search
   generated/man/datalad-aggregate-metadata

Miscellaneous commands
======================

.. toctree::
   :maxdepth: 1

   generated/man/datalad-add-archive-content
   generated/man/datalad-clean
   generated/man/datalad-crawl
   generated/man/datalad-crawl-init
   generated/man/datalad-create-test-dataset
   generated/man/datalad-download-url
   generated/man/datalad-ls
   generated/man/datalad-test
